@@ -21,9 +21,7 @@ from .xmleditor import vmmXMLEditor
 
 
 NUM_COLS = 3
-(COL_LABEL,
- COL_URI,
- COL_CAN_MIGRATE) = range(NUM_COLS)
+(COL_LABEL, COL_URI, COL_CAN_MIGRATE) = range(NUM_COLS)
 
 
 class vmmMigrateDialog(vmmGObjectUI):
@@ -34,35 +32,33 @@ class vmmMigrateDialog(vmmGObjectUI):
                 cls._instance = vmmMigrateDialog()
             cls._instance.show(parentobj.topwin, vm)
         except Exception as e:  # pragma: no cover
-            parentobj.err.show_err(
-                    _("Error launching migrate dialog: %s") % str(e))
+            parentobj.err.show_err(_("Error launching migrate dialog: %s") % str(e))
 
     def __init__(self):
         vmmGObjectUI.__init__(self, "migrate.ui", "vmm-migrate")
         self.vm = None
 
-        self._xmleditor = vmmXMLEditor(self.builder, self.topwin,
-                self.widget("details-box-align"),
-                self.widget("details-box"))
-        self._xmleditor.connect("xml-requested",
-                self._xmleditor_xml_requested_cb)
+        self._xmleditor = vmmXMLEditor(
+            self.builder, self.topwin, self.widget("details-box-align"), self.widget("details-box")
+        )
+        self._xmleditor.connect("xml-requested", self._xmleditor_xml_requested_cb)
 
-        self.builder.connect_signals({
-            "on_vmm_migrate_delete_event": self._delete_event,
-            "on_migrate_cancel_clicked": self._cancel_clicked,
-            "on_migrate_finish_clicked": self._finish_clicked,
-
-            "on_migrate_dest_changed": self._destconn_changed,
-            "on_migrate_set_address_toggled": self._set_address_toggled,
-            "on_migrate_set_port_toggled": self._set_port_toggled,
-            "on_migrate_mode_changed": self._mode_changed,
-        })
+        self.builder.connect_signals(
+            {
+                "on_vmm_migrate_delete_event": self._delete_event,
+                "on_migrate_cancel_clicked": self._cancel_clicked,
+                "on_migrate_finish_clicked": self._finish_clicked,
+                "on_migrate_dest_changed": self._destconn_changed,
+                "on_migrate_set_address_toggled": self._set_address_toggled,
+                "on_migrate_set_port_toggled": self._set_port_toggled,
+                "on_migrate_mode_changed": self._mode_changed,
+            }
+        )
         self.bind_escape_key_close()
         self._cleanup_on_app_close()
 
         self._init_state()
 
-
     def _cleanup(self):
         self.vm = None
         self._xmleditor.cleanup()
@@ -76,7 +72,6 @@ class vmmMigrateDialog(vmmGObjectUI):
     def conn(self):
         return self.vm and self.vm.conn or None
 
-
     ##############
     # Public API #
     ##############
@@ -106,7 +101,6 @@ class vmmMigrateDialog(vmmGObjectUI):
             newvm.conn.connect("vm-removed", self._vm_removed_cb)
         self.vm = newvm
 
-
     ################
     # Init helpers #
     ################
@@ -123,18 +117,19 @@ class vmmMigrateDialog(vmmGObjectUI):
         text = uiutil.init_combo_text_column(combo, COL_LABEL)
         text.set_property("ellipsize", Pango.EllipsizeMode.MIDDLE)
         text.set_property("width-chars", 30)
-        combo.add_attribute(text, 'sensitive', COL_CAN_MIGRATE)
+        combo.add_attribute(text, "sensitive", COL_CAN_MIGRATE)
         model.set_sort_column_id(COL_LABEL, Gtk.SortType.ASCENDING)
 
         def _sorter(model, iter1, iter2, ignore):
             def _cmp(a, b):
-                return ((a > b) - (a < b))
+                return (a > b) - (a < b)
 
             row1 = model[iter1]
             row2 = model[iter2]
             if row1[COL_URI] is None:
                 return -1
             return _cmp(row1[COL_LABEL], row2[COL_LABEL])
+
         model.set_sort_func(COL_LABEL, _sorter)
 
         # Mode combo
@@ -149,11 +144,14 @@ class vmmMigrateDialog(vmmGObjectUI):
         self.widget("migrate-dest").emit("changed")
 
         self.widget("migrate-mode").set_tooltip_text(
-            self.widget("migrate-mode-label").get_tooltip_text())
+            self.widget("migrate-mode-label").get_tooltip_text()
+        )
         self.widget("migrate-unsafe").set_tooltip_text(
-            self.widget("migrate-unsafe-label").get_tooltip_text())
+            self.widget("migrate-unsafe-label").get_tooltip_text()
+        )
         self.widget("migrate-temporary").set_tooltip_text(
-            self.widget("migrate-temporary-label").get_tooltip_text())
+            self.widget("migrate-temporary-label").get_tooltip_text()
+        )
 
     def _reset_state(self):
         self._xmleditor.reset_state()
@@ -192,7 +190,6 @@ class vmmMigrateDialog(vmmGObjectUI):
 
         self._populate_destconn()
 
-
     #############
     # Listeners #
     #############
@@ -234,23 +231,22 @@ class vmmMigrateDialog(vmmGObjectUI):
 
             tunnel_uri = destconn.get_uri()
             if not destconn.is_remote():
-                tunnel_warning = _("A remotely accessible libvirt URI "
+                tunnel_warning = _(
+                    "A remotely accessible libvirt URI "
                     "is required for tunneled migration, but the "
                     "selected connection is a local URI. Libvirt will "
-                    "reject this unless you add a transport.")
-                tunnel_warning = ("<span size='small'>%s</span>" %
-                    tunnel_warning)
+                    "reject this unless you add a transport."
+                )
+                tunnel_warning = "<span size='small'>%s</span>" % tunnel_warning
 
             address = destconn.libvirt_gethostname()
 
         self.widget("migrate-address").set_text(address)
 
         self.widget("migrate-tunnel-uri").set_text(tunnel_uri)
-        uiutil.set_grid_row_visible(
-            self.widget("migrate-tunnel-warning-box"), bool(tunnel_warning))
+        uiutil.set_grid_row_visible(self.widget("migrate-tunnel-warning-box"), bool(tunnel_warning))
         self.widget("migrate-tunnel-warning-label").set_markup(tunnel_warning)
 
-
     def _set_address_toggled(self, src):
         enable = src.get_active()
         self.widget("migrate-address").set_visible(enable)
@@ -274,7 +270,6 @@ class vmmMigrateDialog(vmmGObjectUI):
         self.widget("migrate-direct-box").set_visible(not is_tunnel)
         self.widget("migrate-tunnel-box").set_visible(is_tunnel)
 
-
     ###########################
     # destconn combo handling #
     ###########################
@@ -309,8 +304,7 @@ class vmmMigrateDialog(vmmGObjectUI):
             rows.append(self._build_dest_row(conn))
 
         if not any([row[COL_CAN_MIGRATE] for row in rows]):
-            rows.insert(0,
-                [_("No usable connections available."), None, False])
+            rows.insert(0, [_("No usable connections available."), None, False])
 
         for row in rows:
             model.append(row)
@@ -321,7 +315,6 @@ class vmmMigrateDialog(vmmGObjectUI):
                 combo.set_active(idx)
                 break
 
-
     ####################
     # migrate handling #
     ####################
@@ -378,9 +371,7 @@ class vmmMigrateDialog(vmmGObjectUI):
                 uri = self._build_regular_migrate_uri()
         except Exception as e:  # pragma: no cover
             details = "".join(traceback.format_exc())
-            self.err.show_err((_("Uncaught error validating input: %s") %
-                               str(e)),
-                               details=details)
+            self.err.show_err((_("Uncaught error validating input: %s") % str(e)), details=details)
             return
 
         self.set_finish_cursor()
@@ -395,11 +386,16 @@ class vmmMigrateDialog(vmmGObjectUI):
         progWin = vmmAsyncJob(
             self._async_migrate,
             [self.vm, destconn, uri, tunnel, unsafe, temporary, xml],
-            self._finish_cb, [destconn],
+            self._finish_cb,
+            [destconn],
             _("Migrating VM '%s'") % self.vm.get_name(),
-            (_("Migrating VM '%(name)s' to %(host)s. This may take a while.") %
-                {"name": self.vm.get_name(), "host": destlabel}),
-            self.topwin, cancel_cb=cancel_cb)
+            (
+                _("Migrating VM '%(name)s' to %(host)s. This may take a while.")
+                % {"name": self.vm.get_name(), "host": destlabel}
+            ),
+            self.topwin,
+            cancel_cb=cancel_cb,
+        )
         progWin.run()
 
     def _cancel_migration(self, asyncjob, vm):
@@ -413,8 +409,9 @@ class vmmMigrateDialog(vmmGObjectUI):
 
         asyncjob.job_canceled = True  # pragma: no cover
 
-    def _async_migrate(self, asyncjob,
-            origvm, origdconn, migrate_uri, tunnel, unsafe, temporary, xml):
+    def _async_migrate(
+        self, asyncjob, origvm, origdconn, migrate_uri, tunnel, unsafe, temporary, xml
+    ):
         meter = asyncjob.get_meter()
 
         srcconn = origvm.conn
@@ -423,11 +420,11 @@ class vmmMigrateDialog(vmmGObjectUI):
         vminst = srcconn.get_backend().lookupByName(origvm.get_name())
         vm = vmmDomain(srcconn, vminst, vminst.UUID())
 
-        log.debug("Migrating vm=%s from %s to %s", vm.get_name(),
-                      srcconn.get_uri(), dstconn.get_uri())
+        log.debug(
+            "Migrating vm=%s from %s to %s", vm.get_name(), srcconn.get_uri(), dstconn.get_uri()
+        )
 
-        vm.migrate(dstconn, migrate_uri, tunnel, unsafe, temporary, xml,
-            meter=meter)
+        vm.migrate(dstconn, migrate_uri, tunnel, unsafe, temporary, xml, meter=meter)
 
     ################
     # UI listeners #
